@@ -2,7 +2,7 @@ package Test2::Plugin::DBIProfile;
 use strict;
 use warnings;
 
-our $VERSION = '0.002005';
+our $VERSION = '0.002006';
 
 use DBI::Profile qw/dbi_profile_merge_nodes/;
 use Test2::API qw/test2_add_callback_exit context/;
@@ -35,14 +35,12 @@ sub import {
     test2_add_callback_exit($callback);
 
     # Fallback
-    eval 'END { local $?; $callback->() }; 1' or die $@;
+    eval 'END { local $?; my $ctx = context(); $callback->($ctx); $ctx->release }; 1' or die $@;
 }
 
 sub send_profile_event {
     my ($ctx, $real, $new) = @_;
 
-    $ctx //= context();
-
     my $p = $DBI::shared_profile or return;
 
     my $data = $p->{Data};
